==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/streampipes-model/src/test/java/org/apache/streampipes/model/runtime/TestEventFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.model.runtime;

import org.junit.Test;

import java.util.Map;

import static org.junit.Assert.assertEquals;

public class TestEventFactory {

  @Test
  public void testMapGeneration() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.simpleMap();
    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    assertEquals(1, event.getFields().keySet().size());
    assertEquals("timestamp", event.getFieldByRuntimeName("timestamp").getFieldNameIn());
    assertEquals("timestamp", event.getFieldBySelector("s0::timestamp").getFieldNameIn());
  }

  @Test
  public void testNestedMapGeneration() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.nestedMap();

    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    assertEquals(2, event.getFields().size());
    assertEquals("nested", event.getFieldBySelector("s0::nested").getFieldNameIn());
    assertEquals("timestamp2", event.getFieldBySelector("s0::nested::timestamp2").getFieldNameIn());
  }
}

==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/streampipes-model/src/test/java/org/apache/streampipes/model/runtime/TestEventFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.model.runtime;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.Map;

public class TestEventFactory {

  @Test
  public void testMapGeneration() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.simpleMap();
    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    Assertions.assertEquals(1,
                            event.getFields().keySet().size()
    );
    Assertions.assertEquals("timestamp",
                            event.getFieldByRuntimeName("timestamp").getFieldNameIn());
    Assertions.assertEquals("timestamp",
                            event.getFieldBySelector("s0::timestamp").getFieldNameIn());
  }

  @Test
  public void testNestedMapGeneration() {
    Map<String, Object> runtimeMap = RuntimeTestUtils.nestedMap();

    Event event = RuntimeTestUtils.makeSimpleEvent(runtimeMap, RuntimeTestUtils.getSourceInfo());

    Assertions.assertEquals(2,
                            event.getFields().size()
    );
    Assertions.assertEquals("nested",
                            event.getFieldBySelector("s0::nested").getFieldNameIn());
    Assertions.assertEquals("timestamp2",
                            event.getFieldBySelector("s0::nested::timestamp2").getFieldNameIn());
  }
}
